<?php
include 'is_logged.php'; // Verifica que el usuario está logueado
/* Connect To Database*/
require_once "../db.php";
require_once "../php_conexion.php";
require_once "../funciones.php";
$simbolo_moneda = get_row('perfil', 'moneda', 'id_perfil', 1);

if (isset($_POST['id_cita'])) {
    $id_cita = $_POST['id_cita'];

    // Consulta para obtener el nombre del médico, la fecha y el nombre del paciente basado en la cita
    $query_encabezado = "SELECT c.fecha, p.nombre_paciente AS nombre_paciente, m.nombre AS nombre_medico
                         FROM citas c
                         JOIN pacientes p ON c.paciente = p.id_paciente
                         JOIN medicos m ON c.doctor = m.id_medico
                         WHERE c.id = ?";
    $stmt_encabezado = $conexion->prepare($query_encabezado);
    if ($stmt_encabezado === false) {
        die("Error al preparar la consulta de encabezado: " . $conexion->error);
    }
    $stmt_encabezado->bind_param('i', $id_cita);
    $stmt_encabezado->execute();
    $result_encabezado = $stmt_encabezado->get_result();

    if ($encabezado = $result_encabezado->fetch_assoc()) {
        $nombre_paciente = htmlspecialchars($encabezado['nombre_paciente']);
        $nombre_medico = htmlspecialchars($encabezado['nombre_medico']);
        $fecha_cita = htmlspecialchars($encabezado['fecha']);

        // Mostrar encabezado
        echo "<p><strong>Paciente:</strong> $nombre_paciente</p>";
        echo "<p><strong>Médico:</strong> $nombre_medico</p>";
        echo "<p><strong>Fecha:</strong> $fecha_cita</p>";

        // Consulta para obtener el id_factura basado en la cita
        $query_factura = "SELECT id_factura FROM facturas_ventas WHERE cita_id = ?";
        $stmt_factura = $conexion->prepare($query_factura);
        if ($stmt_factura === false) {
            die("Error al preparar la consulta de factura: " . $conexion->error);
        }
        $stmt_factura->bind_param('i', $id_cita);
        $stmt_factura->execute();
        $result_factura = $stmt_factura->get_result();

        if ($factura = $result_factura->fetch_assoc()) {
            $id_factura = $factura['id_factura'];

            // Consulta para obtener los detalles del tratamiento desde la tabla detalle_fact_ventas
            $query_detalles = "SELECT * FROM detalle_fact_ventas WHERE id_factura = ?";
            $stmt_detalles = $conexion->prepare($query_detalles);
            if ($stmt_detalles === false) {
                die("Error al preparar la consulta de detalles de la factura: " . $conexion->error);
            }
            $stmt_detalles->bind_param('i', $id_factura);
            $stmt_detalles->execute();
            $result_detalles = $stmt_detalles->get_result();

            // Inicializar variables para acumular los totales
            $total_importe = 0;
            $total_descuento = 0;
            $total_final = 0;

            // Verificar si hay detalles
            if ($result_detalles->num_rows > 0) {
                echo "<table class='table table-striped'>";
                echo "<thead><tr><th>Nombre Producto</th><th>Cantidad</th><th>Precio</th><th>Descuento</th><th>Importe</th></tr></thead>";
                echo "<tbody>";

                // Recorrer los detalles
                while ($detalle = $result_detalles->fetch_assoc()) {
                    $id_producto = $detalle['id_producto'];

                    // Obtener el nombre del medicamento
                    $query_producto = "SELECT nombre_medicamento FROM medicamentos WHERE id_medicamento = ?";
                    $stmt_producto = $conexion->prepare($query_producto);
                    if ($stmt_producto === false) {
                        die("Error al preparar la consulta de producto: " . $conexion->error);
                    }
                    $stmt_producto->bind_param('i', $id_producto);
                    $stmt_producto->execute();
                    $result_producto = $stmt_producto->get_result();
                    
                    $nombre_producto = "Desconocido"; // Valor por defecto si no se encuentra el producto
                    if ($producto = $result_producto->fetch_assoc()) {
                        $nombre_producto = $producto['nombre_medicamento'];
                    }

                    // Calcular importe y acumular totales
                    $cantidad = $detalle['cantidad'];
                    $precio = $detalle['precio_venta'];
                    $descuento = $detalle['desc_venta'];
                    $importe = $detalle['importe_venta'];

                    $total_importe += $importe;
                    $total_descuento += $descuento;
                    $total_final += ($importe - $descuento);

                    // Mostrar los detalles en la tabla
                    echo "<tr>";
                    echo "<td>" . htmlspecialchars($nombre_producto) . "</td>";
                    echo "<td>" . htmlspecialchars($cantidad) . "</td>";
                    echo "<td>" . htmlspecialchars($simbolo_moneda . ' ' .$precio) . "</td>";
                    echo "<td>" . htmlspecialchars($descuento) . "</td>";
                    echo "<td>" . htmlspecialchars($simbolo_moneda . ' ' .$importe) . "</td>";
                    echo "</tr>";
                }

                // Mostrar los totales
                echo "<tr>";
                echo "<td colspan='4' class='text-right'><strong>Total Importe:</strong></td>";
                echo "<td><strong>$simbolo_moneda " . number_format($total_importe, 2) . "</strong></td>";
                echo "</tr>";
                echo "<tr>";
                echo "<td colspan='4' class='text-right'><strong>Total Descuento:</strong></td>";
                echo "<td><strong>% " . number_format($total_descuento, 2) . "</strong></td>";
                echo "</tr>";
                echo "<tr>";
                echo "<td colspan='4' class='text-right'><strong>Total Final:</strong></td>";
                echo "<td><strong>$simbolo_moneda " . number_format($total_final, 2) . "</strong></td>";
                echo "</tr>";

                echo "</tbody></table>";
            } else {
                echo "No se encontraron detalles para este tratamiento.";
            }
        } else {
            echo "No se encontró una factura asociada con esta cita.";
        }
    } else {
        echo "No se encontraron detalles para esta cita.";
    }
} else {
    echo "No se recibió el ID de la cita.";
}
?>
