<?php
require('libs/fpdf.php');
require_once "../db.php";
require_once "../php_conexion.php";

// Verificar si el parámetro 'id_medico' está presente y es un valor válido, si no, mostrar todos los pacientes
if (isset($_GET['id_medico']) && is_numeric($_GET['id_medico']) && $_GET['id_medico'] != '') {
    $medicoId = $_GET['id_medico'];

    // Función para obtener los datos de los pacientes filtrados por el id_medico
    function obtenerDatosPacientes($conexion, $medicoId) {
        $query = "SELECT * FROM pacientes INNER JOIN medicos ON pacientes.dr_cabecera = medicos.id_medico WHERE pacientes.dr_cabecera = ?";
        $stmt = $conexion->prepare($query);
        $stmt->bind_param("i", $medicoId);  // "i" es para un entero (id_medico)
        $stmt->execute();
        $resultado = $stmt->get_result();

        $datosPacientes = array();
        while ($fila = $resultado->fetch_assoc()) {
            $datosPacientes[] = $fila;
        }

        return $datosPacientes;
    }

    // Obtener datos de los pacientes para el médico seleccionado
    $pacientes = obtenerDatosPacientes($conexion, $medicoId);

} else {
    // Si no se ha proporcionado un id_medico o es inválido, mostrar todos los pacientes con la combinación con la tabla 'medicos'
    $query = "SELECT * FROM pacientes INNER JOIN medicos ON pacientes.dr_cabecera = medicos.id_medico";
    $resultado = mysqli_query($conexion, $query);

    $pacientes = array();
    while ($fila = mysqli_fetch_assoc($resultado)) {
        $pacientes[] = $fila;
    }
}


class PDF extends FPDF {
    // Encabezado
    function Header() {
        $this->SetFont('Arial', 'B', 14);
        $this->SetTextColor(33, 37, 41); // Color del texto
        $this->Cell(0, 10, utf8_decode('Reporte de Pacientes'), 0, 1, 'C');
        $this->SetFont('Arial', '', 10);
        $this->Cell(0, 10, utf8_decode('Generado el: ') . date('d/m/Y'), 0, 1, 'C');
        $this->Ln(5); // Espacio adicional
    }

    // Pie de página
    function Footer() {
        $this->SetY(-15);
        $this->SetFont('Arial', 'I', 8);
        $this->SetTextColor(100, 100, 100);
        $this->Cell(0, 10, utf8_decode('Página ') . $this->PageNo(), 0, 0, 'C');
    }

    // Función para dibujar una fila correctamente
    function Row($data, $colAnchuras) {
        $maxAltura = $this->GetMaxRowHeight($data, $colAnchuras);

        // Verificar si hay suficiente espacio en la página
        if ($this->GetY() + $maxAltura > $this->PageBreakTrigger) {
            $this->AddPage(); // Añadir nueva página si es necesario
        }

        // Dibujar las celdas con MultiCell
        foreach ($data as $i => $texto) {
            $x = $this->GetX();
            $y = $this->GetY();

            // Dibujar el borde de la celda
            $this->Rect($x, $y, $colAnchuras[$i], $maxAltura);

            // Imprimir el texto dentro de la celda
            $this->MultiCell($colAnchuras[$i], 5, utf8_decode($texto), 0, 'L');

            // Restablecer posición para la próxima celda
            $this->SetXY($x + $colAnchuras[$i], $y);
        }

        // Mover el cursor hacia abajo para la siguiente fila
        $this->Ln($maxAltura);
    }

    // Calcular la altura máxima de una fila
    function GetMaxRowHeight($data, $colAnchuras) {
        $maxAltura = 0;
        foreach ($data as $i => $texto) {
            $altura = $this->GetMultiCellHeight($colAnchuras[$i], 5, $texto);
            if ($altura > $maxAltura) {
                $maxAltura = $altura;
            }
        }
        return $maxAltura;
    }

    // Calcular la altura de una celda MultiCell
    function GetMultiCellHeight($w, $h, $text) {
        $lines = $this->NbLines($w, utf8_decode($text));
        return $lines * $h;
    }

    // Calcular el número de líneas en una MultiCell
    function NbLines($w, $text) {
        $cw = &$this->CurrentFont['cw'];
        if ($w == 0) {
            $w = $this->w - $this->rMargin - $this->x;
        }
        $wmax = ($w - 2 * $this->cMargin) * 1000 / $this->FontSize;
        $s = str_replace("\r", '', $text);
        $nb = strlen($s);
        if ($nb > 0 && $s[$nb - 1] == "\n") {
            $nb--;
        }
        $sep = -1;
        $i = 0;
        $j = 0;
        $l = 0;
        $nl = 1;
        while ($i < $nb) {
            $c = $s[$i];
            if ($c == "\n") {
                $i++;
                $sep = -1;
                $j = $i;
                $l = 0;
                $nl++;
                continue;
            }
            if ($c == ' ') {
                $sep = $i;
            }
            $l += $cw[$c];
            if ($l > $wmax) {
                if ($sep == -1) {
                    if ($i == $j) {
                        $i++;
                    }
                } else {
                    $i = $sep + 1;
                }
                $sep = -1;
                $j = $i;
                $l = 0;
                $nl++;
            } else {
                $i++;
            }
        }
        return $nl;
    }
}

// Crear el PDF
$pdf = new PDF('L', 'mm', 'A4');
$pdf->AddPage();

// Definir encabezados y anchos de columnas
$colAnchuras = [20, 50, 30, 70, 30, 40, 40];
$encabezados = ['ID', 'Nombre', 'DUI', 'Dirección', 'Teléfono', 'Fecha Nacimiento', 'Medico'];

// Encabezados
$pdf->SetFont('Arial', 'B', 10);
$pdf->SetFillColor(230, 230, 230);
$pdf->SetTextColor(0, 0, 0);
foreach ($encabezados as $i => $titulo) {
    $pdf->Cell($colAnchuras[$i], 10, utf8_decode($titulo), 1, 0, 'C', true);
}
$pdf->Ln();

// Datos
$pdf->SetFont('Arial', '', 9);
$pdf->SetTextColor(50, 50, 50);
foreach ($pacientes as $paciente) {
    $pdf->Row([
        $paciente['id_paciente'],
        $paciente['nombre_paciente'],
        $paciente['dui_paciente'],
        $paciente['direccion_paciente'],
        $paciente['tel_paciente'],
        $paciente['fecha_nacimiento'],
        $paciente['nombre']
    ], $colAnchuras);
}

// Salida del PDF
$pdf->Output();
?>
