<?php
require('libs/fpdf.php');
// Incluir archivo de configuración y función de conexión
require_once "../db.php";
require_once "../php_conexion.php";
// Archivo de funciones PHP
require_once "../funciones.php";

// Función para obtener datos de un paciente específico
function obtenerDatosPaciente($conexion, $id_paciente) {
    $query = "SELECT * FROM pacientes, medicos WHERE pacientes.dr_cabecera = medicos.id_medico AND pacientes.id_paciente = $id_paciente";
    $resultado = mysqli_query($conexion, $query);
    $paciente = mysqli_fetch_assoc($resultado);
    return $paciente;
}

class PDF extends FPDF {
    private $fill = false; // Variable para alternar colores

    // Encabezado del reporte
    function Header() {
        // Logo en el lado derecho
        $logo_url = get_row('perfil', 'logo_url', 'id_perfil', 1);
        $this->Image($logo_url, 160, 10, 30);
        
        // Título del reporte
        $this->SetFont('Arial', 'B', 16);
        $this->Cell(0, 10, 'Perfil de Paciente', 0, 1, 'C');
        $this->SetFont('Arial', '', 12);
        $this->Cell(0, 10, 'Información detallada del paciente', 0, 1, 'C');
        $this->Ln(10); // Espacio después del título
    }

    // Pie de página
    function Footer() {
        $this->SetY(-15);
        $this->SetFont('Arial', 'I', 8);
        $this->Cell(0, 10, 'Página ' . $this->PageNo(), 0, 0, 'C');
    }

    // Tabla coloreada
    function ColoredTable($header, $data) {
        // Colores, ancho de línea y fuente en negrita
        $this->SetFillColor(200, 220, 255);
        $this->SetTextColor(0);
        $this->SetDrawColor(0, 0, 0);
        $this->SetLineWidth(.3);
        $this->SetFont('Arial', 'B', 12);

        // Ancho de cada columna
        $w = array(50, 120); // Personaliza el ancho de las columnas según tus necesidades

        // Cabecera
        $this->Cell($w[0], 8, utf8_decode($header[0]), 1, 0, 'C', true);
        $this->Cell($w[1], 8, utf8_decode($header[1]), 1, 0, 'C', true);
        $this->Ln();

        // Restauración de colores y fuentes
        $this->SetFillColor(224, 235, 255);
        $this->SetTextColor(0);
        $this->SetFont('Arial', '', 12);

        // Datos
        foreach ($data as $row) {
            $this->Cell($w[0], 8, utf8_decode($row[0]), 'LR', 0, 'L', $this->fill);
            $this->Cell($w[1], 8, utf8_decode($row[1]), 'LR', 0, 'L', $this->fill);
            $this->Ln();
            $this->fill = !$this->fill; // Alternar color en cada fila
        }

        // Línea de cierre
        $this->Cell(array_sum($w), 0, '', 'T');
    }
}

// Obtener el ID del paciente desde el parámetro en la URL
$id_paciente = $_GET['id_paciente'];

// Obtener datos del paciente específico
$paciente = obtenerDatosPaciente($conexion, $id_paciente);

// Crear instancia de PDF
$pdf = new PDF();
$pdf->AddPage();

// Título con los datos del paciente
$pdf->SetFont('Arial', 'B', 12);
$pdf->Cell(0, 10, 'Nombre del Paciente:', 0, 1);
$pdf->SetFont('Arial', '', 12);
$pdf->Cell(0, 10, utf8_decode($paciente['nombre_paciente']), 0, 1);

$pdf->SetFont('Arial', 'B', 12);
$pdf->Cell(0, 10, utf8_decode('Información Detallada:'), 0, 1);
$pdf->Ln(5);

// Crear datos para la tabla
$pdf->SetFont('Arial', '', 10);
$header = array('Campo', 'Valor');
$data = array(
    array('ID', utf8_decode($paciente['id_paciente'])),
    array('DUI', utf8_decode($paciente['dui_paciente'])),
    array('Dirección', utf8_decode($paciente['direccion_paciente'])),
    array('Teléfono', utf8_decode($paciente['tel_paciente'])),
    array('Encargado Paciente', utf8_decode($paciente['encargado_paciente'])),
    array('Dr. Cabecera', utf8_decode($paciente['nombre'])),
    array('Fecha de Nacimiento', utf8_decode($paciente['fecha_nacimiento']) . ' - ' . utf8_decode($paciente['edad_paciente']) . ' Años'),
    array('Otros Datos', utf8_decode($paciente['otros'])),
    array('Comentarios', utf8_decode($paciente['comentarios']))
);

// Crear tabla coloreada
$pdf->ColoredTable($header, $data);

// Salida del PDF
$pdf->Output();

// Cerrar la conexión a la base de datos al finalizar
mysqli_close($conexion);
?>
